# author：灵岩（1318215328@qq.com）
#coding=utf-8
# 创建于: 11/30 0027 16:26

from distutils.core import setup
setup(
    name = 'zyw',
    version='1.0.0',
    author = '灵岩',
    author_email='1318215328@qq.com',
    # py_modules = 'zyw',
    url = 'http://www.xxxxx.com',
    description='这是一个测试打包的过程',
    py_modules = ['zyw']
)